local PipelineBuild(arch='amd64') = {
  local tag = 'linux-' + arch,
  kind: 'pipeline',
  name: 'build-container-' + arch,
  platform: {
    os: 'linux',
    arch: arch,
  },
  steps: [
    {
      name: 'dryrun',
      image: 'plugins/docker:' + tag,
      settings: {
        dry_run: true,
        dockerfile: './Dockerfile.' + arch,
        repo: 'xoxys/nginx',
        username: { from_secret: 'docker_username' },
        password: { from_secret: 'docker_password' },
      },
      when: {
        ref: [
          'refs/pull/**',
        ],
      },
    },
    {
      name: 'publish',
      image: 'plugins/docker:' + tag,
      settings: {
        auto_tag: true,
        auto_tag_suffix: arch,
        dockerfile: './Dockerfile.' + arch,
        repo: 'xoxys/nginx',
        username: { from_secret: 'docker_username' },
        password: { from_secret: 'docker_password' },
      },
      when: {
        ref: [
          'refs/heads/master',
          'refs/tags/**',
        ],
      },
    },
  ],
};

local PipelineNotifications(depends_on=[]) = {
  kind: 'pipeline',
  name: 'notifications',
  platform: {
    os: 'linux',
    arch: 'amd64',
  },
  steps: [
    {
      image: 'plugins/manifest',
      name: 'manifest',
      settings: {
        ignore_missing: true,
        username: { from_secret: 'docker_username' },
        password: { from_secret: 'docker_password' },
        spec: './manifest.tmpl',
      },
    },
    {
      name: 'readme',
      image: 'sheogorath/readme-to-dockerhub',
      environment: {
        DOCKERHUB_USERNAME: { from_secret: 'docker_username' },
        DOCKERHUB_PASSWORD: { from_secret: 'docker_password' },
        DOCKERHUB_REPO_PREFIX: 'xoxys',
        DOCKERHUB_REPO_NAME: 'nginx',
        README_PATH: 'README.md',
        SHORT_DESCRIPTION: 'Rootless NGINX - High-performance HTTP server and reverse proxy',
      },
    },
    {
      image: 'plugins/matrix',
      name: 'matrix',
      settings: {
        homeserver: 'https://matrix.rknet.org',
        roomid: 'MtidqQXWWAtQcByBhH:rknet.org',
        template: 'Status: **{{ build.status }}**<br/> Build: [{{ repo.Owner }}/{{ repo.Name }}]({{ build.link }}) ({{ build.branch }}) by {{ build.author }}<br/> Message: {{ build.message }}',
        username: { from_secret: 'matrix_username' },
        password: { from_secret: 'matrix_password' },
      },
      when: {
        status: ['success', 'failure'],
      },
    },
  ],
  trigger: {
    ref: [
      'refs/heads/master',
      'refs/tags/**',
    ],
    status: ['success', 'failure'],
  },
  depends_on: depends_on,
};

[
  PipelineBuild(arch='amd64'),
  PipelineNotifications(depends_on=[
    'build-container-amd64',
  ]),
]
